@@ -181,10 +181,14 @@ class S3(object):
         for cmd in CMD_DICT.keys():
             cmd_specification = CMD_DICT[cmd]
             cmd_class = cmd_specification.get('command_class', S3SubCommand)
-
+            # If a cmd_class is provided, the we'll try to grab the
+            # description and usage off of that object, otherwise
+            # we'll look in the command dict.
+            description, usage = self._get_command_usage(cmd_class)
             subcommand_table[cmd] = cmd_class(
                 cmd, self._session, cmd_specification['options'],
-                cmd_specification['description'], cmd_specification['usage'])
+                cmd_specification.get('description', description),
+                cmd_specification.get('usage', usage))
 
         self._session.emit('building-operation-table.%s' % self._name,
                            operation_table=subcommand_table,
@@ -194,6 +198,10 @@ class S3(object):
                                                 arg_table=None)
         return subcommand_table
 
+    def _get_command_usage(self, cmd_class):
+        return (getattr(cmd_class, 'DESCRIPTION', None),
+                getattr(cmd_class, 'USAGE', None))
+
     def create_help_command(self):
         """
         This function returns a help command object with a filled command
@@ -210,6 +218,8 @@ class S3SubCommand(object):
     """
     This is the object corresponding to a S3 subcommand.
     """
+    DESCRIPTION = None
+    USAGE = None
 
     def __init__(self, name, session, options, documentation="", usage=""):
         """
@@ -399,6 +409,41 @@ class ListCommand(S3SubCommand):
         return size_str.rjust(10, ' ')
 
 
+class WebsiteCommand(S3SubCommand):
+    DESCRIPTION = 'Set the website configuration for a bucket.'
+    USAGE = 's3://bucket [--index-document|--error-document] value'
+
+    def _do_command(self, parsed_args, parsed_globals):
+        service = self._session.get_service('s3')
+        endpoint = service.get_endpoint(parsed_globals.region)
+        operation = service.get_operation('PutBucketWebsite')
+        bucket = self._get_bucket_name(parsed_args.paths[0])
+        website_configuration = self._build_website_configuration(parsed_args)
+        operation.call(endpoint, bucket=bucket,
+                       website_configuration=website_configuration)
+        return 0
+
+    def _build_website_configuration(self, parsed_args):
+        website_config = {}
+        if parsed_args.index_document is not None:
+            website_config['IndexDocument'] = {'Suffix': parsed_args.index_document}
+        elif parsed_args.error_document is not None:
+            website_config['ErrorDocument'] = {'Key': parsed_args.error_document}
+        return website_config
+
+    def _get_bucket_name(self, path):
+        # We support either:
+        # s3://bucketname
+        # bucketname
+        #
+        # We also strip off the trailing slash if a user
+        # accidently appends a slash.
+        if path.startswith('s3://'):
+            path = path[5:]
+        if path.endswith('/'):
+            path = path[:-1]
+        return path
+
 
 class S3Parameter(BaseCLIArgument):
     """
@@ -612,9 +657,7 @@ class CommandParameters(object):
         endpoint = service.get_endpoint(self.parameters['region'])
         operation = service.get_operation('ListObjects')
         # This will raise an exception if the bucket does not exist.
-        html_response, response_data = operation.call(endpoint,
-                                                      bucket=bucket_name,
-                                                      max_keys=0)
+        operation.call(endpoint, bucket=bucket_name, max_keys=0)
 
     def check_path_type(self, paths):
         """
@@ -668,10 +711,8 @@ class CommandParameters(object):
                     src_path += '/'  # all prefixes must end with a /
             bucket, key = find_bucket_key(src_path)
             operation = service.get_operation('ListObjects')
-            html_response, response_data = operation.call(endpoint,
-                                                          bucket=bucket,
-                                                          prefix=key,
-                                                          delimiter='/')
+            response_data = operation.call(endpoint, bucket=bucket, prefix=key,
+                                           delimiter='/')[1]
             check_error(response_data)
             contents = response_data['Contents']
             common_prefixes = response_data['CommonPrefixes']
@@ -706,8 +747,8 @@ class CommandParameters(object):
         """
         if 'force' in self.parameters:
             if self.parameters['force']:
-                bucket, key = find_bucket_key(self.parameters['src'][5:])
-                path = 's3://'+bucket
+                bucket = find_bucket_key(self.parameters['src'][5:])[0]
+                path = 's3://' + bucket
                 try:
                     del_objects = S3SubCommand('rm', self.session, {'nargs': 1})
                     del_objects([path, '--recursive'], parsed_globals)
@@ -777,7 +818,10 @@ CMD_DICT = {'cp': {'options': {'nargs': 2},
                    'params': [], 'default': 's3://',
                    'command_class': ListCommand},
             'mb': {'options': {'nargs': 1}, 'params': []},
-            'rb': {'options': {'nargs': 1}, 'params': ['force']}
+            'rb': {'options': {'nargs': 1}, 'params': ['force']},
+            'website': {'options': {'nargs': 1},
+                        'params': ['index-document', 'error-document'],
+                        'command_class': WebsiteCommand},
             }
 
 add_command_descriptions(CMD_DICT)
@@ -816,8 +860,16 @@ PARAMS_DICT = {'dryrun': {'options': {'action': 'store_true'}},
                'content-encoding': {'options': {'nargs': 1}},
                'content-language': {'options': {'nargs': 1}},
                'expires': {'options': {'nargs': 1}},
+               'index-document': {'options': {}, 'documents':
+                   ('A suffix that is appended to a request that is for a '
+                    'directory on the website endpoint (e.g. if the suffix '
+                    'is index.html and you make a request to '
+                    'samplebucket/images/ the data that is returned will '
+                    'be for the object with the key name images/index.html) '
+                    'The suffix must not be empty and must not include a '
+                    'slash character.')},
+               'error-document': {'options': {}, 'documents':
+                   'The object key name to use when a 4XX class error occurs.'}
+
                }
-
 add_param_descriptions(PARAMS_DICT)
-
-
